import { getSkdAssignmentStore } from "../../utils/schedulerAssignment";
import { getSkdDependencyStore } from "../../utils/schedulerDependency";
import { getSkdEventStore } from "../../utils/schedulerEvent";
import { getSkdResourceStore } from "../../utils/schedulerResource";
import { InitSchedulerGanttView } from "./schedulerGanttView";


export let schedulerInstance = null;

const Scheduler = () => {
    
    let parameters = {
        gantt: {
            "htmlContainerName" : 'scheduler-gantt-wrapper',
            "startDate" : '2023-01-17', 
            "endDate" : '2023-01-30', 
        }, 
        table: {
            "htmlContainerName" : 'scheduler-table-wrapper',
        }
    }

    var _inlinestyle = 
    `
        height: 100%;
        width: 100%;
    `;

    const template = `<div style="${_inlinestyle}" id="${parameters.gantt.htmlContainerName}"></div>
                      <div hidden style="${_inlinestyle}" id="${parameters.table.htmlContainerName}"></div>`;


    window.setTimeout(() => {
        
        parameters.gantt.resourceStore = getSkdResourceStore();
        parameters.gantt.eventStore = getSkdEventStore();
        parameters.gantt.assignmentStore = getSkdAssignmentStore();
        parameters.gantt.dependencyStore = getSkdDependencyStore();

        parameters.gantt.viewPreset = timeAxisGranularity(parameters.gantt.startDate, parameters.gantt.endDate);

        schedulerInstance = InitSchedulerGanttView(parameters.gantt);

        parameters.table.schedulerInstance = schedulerInstance;
    }, 0)


    return template;
};

function timeAxisGranularity(startDate, endDate) {
    if (typeof startDate === 'string' || startDate instanceof String) {
        startDate = new Date(startDate)
    }
    if (typeof endDate === 'string' || endDate instanceof String) {
        endDate = new Date(endDate)
    }

    // To calculate the no. of days between two dates
    var days = (endDate - startDate) / (1000 * 3600 * 24);

    let func_value; // 20 => 10 min, 50 => 30 min, 100 => 1 hours, 200 => 2 hours, 300 => 3 hours, 400 => 4 hours, 500 => 1 day

    if (days <= 1) { //granularity = 30 min
        func_value = "50"
    }
    else if (days > 1 && days <= 7) { //granularity = 2h
        func_value = "200"
    }
    // if campaignDays > 7
    else { //granularity = 1 day
        func_value = "500"
    }
    
    return getViewPreset(func_value);
}

function getViewPreset(value) {
    // 20 => 10 min
    // 50 => 30 min
    // 100 => 1 hours
    // 200 => 2 hours
    // 300 => 3 hours
    // 400 => 4 hours
    // 500 => 1 day

    let viewPreset = {
        timeResolution : {              // Dates will be snapped to this resolution
            unit      : 'minute',       // Valid values are 'millisecond', 'second', 'minute', 'hour', 'day', 'week', 'month', 'quarter', 'year'.
            increment : 1
        },
    }
    
    switch(value){
        case "20": //10 min
            viewPreset.base = "minuteAndHour",
                
            viewPreset.headers = [          // This defines your header rows from top to bottom
                {                           // For each row you can define 'unit', 'increment', 'dateFormat', 'renderer', 'align', and 'thisObj'
                    unit       : 'day',
                    dateFormat : 'ddd DD/MM',
                    align      : 'start'
                },
                {
                    unit       : 'hour',
                    dateFormat : 'H A'
                },
                {
                    unit       : 'minute',
                    dateFormat : 'HH:mm',
                    increment  : 10,
                }
            ]
            break;
        case "50": //30 min
            viewPreset.base = "minuteAndHour",
                
            viewPreset.headers = [          // This defines your header rows from top to bottom
                {                           // For each row you can define 'unit', 'increment', 'dateFormat', 'renderer', 'align', and 'thisObj'
                    unit       : 'day',
                    dateFormat : 'ddd DD/MM',
                    align      : 'start'
                },
                {
                    unit       : 'hour',
                    dateFormat : 'H A'
                },
                {
                    unit       : 'minute',
                    dateFormat : 'HH:mm',
                    increment  : 30,
                }
            ]
            break;
        case "100": //1 hours
            viewPreset.base = "minuteAndHour",
                
            viewPreset.headers = [          
                {                           
                    unit       : 'day',
                    dateFormat : 'ddd DD/MM',
                    align      : 'start'
                },
                {
                    unit       : 'hour',
                    dateFormat : 'H A'
                }
            ]
            break;
        case "200": //2 hours
            viewPreset.base = "minuteAndHour",
                
            viewPreset.headers = [
                {                           
                    unit       : 'day',
                    dateFormat : 'ddd DD/MM',
                },
                {
                    unit       : 'hour',
                    dateFormat : 'H A',
                    increment  : 2
                }
            ]
            break;
        case "300": //3 hours
            viewPreset.base = "minuteAndHour",
                
            viewPreset.headers = [          
                {                           
                    unit       : 'day',
                    dateFormat : 'ddd DD/MM',
                },
                {
                    unit       : 'hour',
                    dateFormat : 'H A',
                    increment  : 3
                }
            ]
            break;
        case "400": //4 hours
            viewPreset.base = "minuteAndHour",
                
            viewPreset.headers = [         
                {                           
                    unit       : 'day',
                    dateFormat : 'ddd DD/MM',
                },
                {
                    unit       : 'hour',
                    dateFormat : 'H A',
                    increment  : 4
                }
            ]
            break;
        case "500": //1 day
            viewPreset.base = "dayAndWeek";
            break;
        case "600": //week
            viewPreset.base = "weekAndMonth";
            break;
        case "700": //month
            viewPreset.base = "monthAndYear";
            break;
        case "800": //year
            viewPreset.base = "year";
            break;
    }

    return viewPreset;
}

export default Scheduler;