import { SchedulerPro } from "@bryntum/schedulerpro";

export function InitSchedulerGanttView(parameters){
    const scheduler = new SchedulerPro({

        appendTo: parameters.htmlContainerName,
        startDate: parameters.startDate,
        endDate: parameters.endDate,
        rowHeight: 70,
        barMargin: 22,
        eventStyle: 'rounded',
        loadMask : null,
        syncMask : null,
        
        viewPreset: parameters.viewPreset,
        
        features: {
            columnLines: false,
            tree: true,
            filter: true,

            percentBar: { 
                allowResize: false 
            },

            dependencies : {
                allowCreate : false,
            },

            timeAxisHeaderMenu: {
                items: {
                    dateRange: false,
                    zoomLevel: false,
                }
            },

            cellMenu: {
                items: {
                    removeRow: false,
                }
            },

            taskEdit: {
                items: {
                    generalTab: {
                        items: {
                            nameField: {
                                readOnly: true,
                            },
                            resourcesField: {
                                readOnly: true,
                            },
                            percentDoneField: {
                                readOnly: true,
                            }
                        }
                    },
                    predecessorsTab: {
                        items: {
                            toolbar: {
                                items: {
                                    remove: false,
                                    add: false,
                                }
                            }
                        }
                    },
                    successorsTab: {
                        items: {
                            toolbar: {
                                items: {
                                    remove: false,
                                    add: false,
                                }
                            }
                        }
                    },
                    advancedTab: false,
                }
            },

            eventMenu: {
                items: {
                    cutEvent: false,
                    deleteEvent: false,
                    lockEvent: {
                        text: "Lock",
                        icon: "b-fa b-fa-fw b-fa-lock",
                        weight: 400,
                        onItem : ({ eventRecord }) => {
                            eventRecord.set('locked', 'true')
                            eventRecord.iconCls = "b-fa b-fa-fw b-fa-lock"; 
                            // eventRecord.setAsync('locked', 'true').then(() => {
                            //     eventRecord.iconCls = "b-fa b-fa-fw b-fa-lock"; 
                            // });
                        }
                    }, 
                    unlockEvent: {
                        text: "Unlock",
                        icon: "b-fa b-fa-fw b-fa-lock-open",
                        weight: 400,
                        onItem : ({ eventRecord }) => {        
                            eventRecord.set('locked', 'false')
                            eventRecord.iconCls = '';    
                            // eventRecord.setAsync('locked', 'false').then(() => {
                            //     eventRecord.iconCls = ''; 
                            // });
                        }
                    },    
                },

                processItems({ items, eventRecord }){
                    if(eventRecord.get('locked')){
                        items.lockEvent.hidden = true,
                        items.unlockEvent.hidden = false
                    }
                    else{
                        items.lockEvent.hidden = false,
                        items.unlockEvent.hidden = true
                    }
                },
            }
        },

        columns: [
            {
                type: 'tree',
                field: 'name',
                text: 'Machine',
                editor: false,
            },
        ],

    });

    scheduler.eventStore = parameters.eventStore;
    scheduler.resourceStore = parameters.resourceStore;
    scheduler.assignmentStore = parameters.assignmentStore;
    scheduler.dependencyStore = parameters.dependencyStore;

    return scheduler;   
}